@@ -1,3 +1,4 @@
+from concurrent.futures import ThreadPoolExecutor
 from os.path import join
 
 from snakypy.helpers import printer
@@ -45,37 +46,47 @@ class InitCommand(Base):
     def run(self, arguments, *, reload=False, message=False) -> None:
         printer("Please wait ... assigning settings ...", foreground=FG().WARNING)
         tools_requirements("bash", "zsh", "vim", "git", "cut", "grep", "whoami", "pwd")
-        snakypy_path_create(self.data_root)
+        snakypy_path_create(self.data_root, self.cache_root)
         create_config(config_content, self.config_file)
         create_file(set_zshpower_content, self.init_file, force=True)
         # Create table if not exists
         DAO().create_table(self.tbl_main)
         # Insert registers
-        records("insert")
-        loading(
-            set_time=0.040,
-            bar=False,
-            header="ZSHPower is creating the database. Wait a moment...",
-            foreground=FG().QUESTION,
-        )
+        try:
+            with ThreadPoolExecutor(max_workers=2) as executor:
+                executor.submit(
+                    loading,
+                    set_time=0.140,
+                    bar=False,
+                    header="ZSHPower is creating the database. Wait a moment ...",
+                    foreground=FG().QUESTION,
+                )
+                executor.submit(records, action="insert")
+        except KeyboardInterrupt:
+            printer(
+                "This operation cannot be canceled. Wait for the operation.",
+                foreground=FG().WARNING,
+            )
 
         if arguments["--omz"]:
-            omz_install(self.omz_root)
-            omz_install_plugins(self.omz_root, self.plugins)
-            create_zshrc(zshrc_content, self.zsh_rc)
-            change_theme_in_zshrc(self.zsh_rc, f"{__info__['pkg_name']}")
-            add_plugins_zshrc(self.zsh_rc)
+            omz_install(self.omz_root, self.logfile)
+            omz_install_plugins(self.omz_root, self.plugins, self.logfile)
+            create_zshrc(zshrc_content, self.zsh_rc, self.logfile)
+            change_theme_in_zshrc(self.zsh_rc, f"{__info__['pkg_name']}", self.logfile)
+            add_plugins_zshrc(self.zsh_rc, self.logfile)
             create_file(set_zshpower_content, self.theme_file, force=True)
 
-        install_fonts(self.HOME)
-        change_shell()
+        install_fonts(self.HOME, self.logfile)
+        change_shell(self.logfile)
         remove_versions_garbage(join(self.HOME, f".{__info__['pkg_name']}"))
 
         try:
             cron_task(sync_content, self.sync_path, cron_content, self.cron_path)
             printer("Done!", foreground=FG().FINISH) if message else None
 
-            if not arguments["--omz"] and not get_line_source(self.zsh_rc):
+            if not arguments["--omz"] and not get_line_source(
+                self.zsh_rc, self.logfile
+            ):
                 printer(instruction_not_omz, foreground=FG().YELLOW)
 
             if reload:
@@ -84,8 +95,11 @@ class InitCommand(Base):
             printer("Canceled by user", foreground=FG().WARNING)
             printer("Done!", foreground=FG().FINISH) if message else None
 
-            if not arguments["--omz"] and not get_line_source(self.zsh_rc):
+            if not arguments["--omz"] and not get_line_source(
+                self.zsh_rc, self.logfile
+            ):
                 printer(instruction_not_omz, foreground=FG().YELLOW)
 
             if reload:
                 reload_zsh()
+        self.log.record("Initial settings applied", colorize=True, level="info")
