@@ -1,8 +1,8 @@
-from .lib.utils import symbol_ssh, element_spacing
-from .lib.utils import Color
 from os import environ as os_environ
 from socket import gethostname
 
+from .utils import Color, element_spacing, symbol_ssh
+
 
 class Hostname:
     def __init__(self, config):
