@@ -1,14 +1,13 @@
-from os import getcwd
-from os.path import join
-from .lib.utils import symbol_ssh, element_spacing
-from .lib.utils import Color, separator
-from snakypy.zshpower.utils.catch import verify_objects
-from snakypy.helpers.files import read_json
 from contextlib import suppress
-from os.path import isfile, exists
+from os import getcwd
+from os.path import exists, isfile, join
 from subprocess import run
 
-# TODO: REFACTOR
+from snakypy.helpers.files import read_json
+
+from snakypy.zshpower.utils.catch import verify_objects
+
+from .utils import Color, element_spacing, separator, symbol_ssh
 
 
 class Base:
@@ -19,7 +18,11 @@ class Base:
         self.extensions = ()
         self.symbol = symbol_ssh(config["package"]["symbol"], "pkg-")
         self.enable = config["package"]["enable"]
-        self.color = config["package"]["color"]
+        self.color = (
+            config["package"]["color"]
+            if config["general"]["color"]["enable"] is True
+            else "negative"
+        )
         self.prefix_color = config["package"]["prefix"]["color"]
         self.prefix_text = element_spacing(config["package"]["prefix"]["text"])
 
@@ -218,19 +221,3 @@ class Package:
         elif exists(join(getcwd(), Helm(self.config).files[0])):
             return str(Helm(self.config))
         return ""
-
-
-# def package(config):
-#     if exists(join(getcwd(), Python(config).files[0])):
-#         return Python(config)
-#     elif exists(join(getcwd(), Rust(config).files[0])):
-#         return Rust(config)
-#     elif exists(join(getcwd(), NodeJS(config).files[0])):
-#         return NodeJS(config)
-#     elif exists(join(getcwd(), Scala(config).files[0])):
-#         return Scala(config)
-#     elif exists(join(getcwd(), Crystal(config).files[0])):
-#         return Crystal(config)
-#     elif exists(join(getcwd(), Helm(config).files[0])):
-#         return Helm(config)
-#     return ""
