@@ -1,12 +1,18 @@
+from os import environ, getcwd
+from os.path import exists, isdir, isfile, join
 from sys import version_info
-from snakypy.zshpower.utils.catch import verify_objects
+
 from snakypy.helpers.catches import is_tool
 from snakypy.helpers.files import read_file
-from os import environ, getcwd
-from os.path import isfile, join, exists, isdir
+
 from snakypy.zshpower import HOME
-from snakypy.zshpower.prompt.sections.lib.utils import symbol_ssh, element_spacing
-from snakypy.zshpower.prompt.sections.lib.utils import Color, separator
+from snakypy.zshpower.prompt.sections.utils import (
+    Color,
+    element_spacing,
+    separator,
+    symbol_ssh,
+)
+from snakypy.zshpower.utils.catch import verify_objects
 
 
 class Python:
@@ -26,7 +32,11 @@ class Python:
         self.folders = ("__pycache__",)
         self.extensions = (".py",)
         self.symbol = symbol_ssh(config["python"]["symbol"], "py-")
-        self.color = config["python"]["color"]
+        self.color = (
+            config["python"]["color"]
+            if config["general"]["color"]["enable"] is True
+            else "negative"
+        )
         self.prefix_color = config["python"]["prefix"]["color"]
         self.prefix_text = element_spacing(config["python"]["prefix"]["text"])
         self.micro_version_enable = config["python"]["version"]["micro"]["enable"]
@@ -92,7 +102,11 @@ class Virtualenv:
         self.py_enable = config["python"]["virtualenv"]["poetry"]["py"]["enable"]
         self.symbol = symbol_ssh(config["python"]["virtualenv"]["symbol"], "")
         self.involved = config["python"]["virtualenv"]["involved"]
-        self.color = config["python"]["virtualenv"]["color"]
+        self.color = (
+            config["python"]["virtualenv"]["color"]
+            if config["general"]["color"]["enable"] is True
+            else "negative"
+        )
         self.prefix_color = config["python"]["virtualenv"]["prefix"]["color"]
         self.prefix_text = element_spacing(
             config["python"]["virtualenv"]["prefix"]["text"]
