@@ -6,10 +6,12 @@ from re import sub as re_sub
 from shutil import rmtree, which
 from subprocess import PIPE, Popen, check_output
 from sys import platform
+from textwrap import dedent
 from zipfile import ZipFile
 
 from snakypy.helpers import FG, printer
 from snakypy.helpers.files import backup_file, create_file
+from snakypy.helpers.logging import Log
 from snakypy.helpers.path import create as snakypy_path_create
 from snakypy.helpers.subprocess import command
 from tomlkit import dumps as toml_dumps
@@ -32,9 +34,28 @@ def create_config(content, file_path, *, force=False) -> bool:
     return False
 
 
-def create_zshrc(content, zshrc) -> bool:
+def log_base(filename, force=False) -> Log:
+    content = dedent(
+        f"""
+        *******************************
+         {__info__['name']} Logs - version {__info__['version']}
+        *******************************
+
+        | Level | Date | Message |
+
+    """
+    )
+    if not exists(filename):
+        create_file(content, filename, force=force)
+    else:
+        if force:
+            create_file(content, filename, force=force)
+    return Log(filename=filename)
+
+
+def create_zshrc(content, zshrc, logfile) -> bool:
     if exists(zshrc):
-        if not read_zshrc_omz(zshrc):
+        if not read_zshrc_omz(zshrc, logfile):
             backup_file(zshrc, zshrc, date=True, extension=False)
             create_file(content, zshrc, force=True)
             return True
@@ -78,10 +99,10 @@ def cron_task(sync_context, sync_path, cron_context, cron_path):
                 pass_ok = True
 
 
-def change_theme_in_zshrc(zshrc, theme_name) -> bool:
-    if read_zshrc_omz(zshrc):
-        current_zshrc = read_zshrc(zshrc)
-        current_theme = read_zshrc_omz(zshrc)[1]
+def change_theme_in_zshrc(zshrc, theme_name, logfile) -> bool:
+    if read_zshrc_omz(zshrc, logfile):
+        current_zshrc = read_zshrc(zshrc, logfile)
+        current_theme = read_zshrc_omz(zshrc, logfile)[1]
         new_theme = f'ZSH_THEME="{theme_name}"'
         new_zsh_rc = re_sub(rf"{current_theme}", new_theme, current_zshrc, flags=re_m)
         create_file(new_zsh_rc, zshrc, force=True)
@@ -89,7 +110,7 @@ def change_theme_in_zshrc(zshrc, theme_name) -> bool:
     return False
 
 
-def omz_install(omz_root):
+def omz_install(omz_root, logfile):
     omz_github = "https://github.com/ohmyzsh/ohmyzsh.git"
     cmd_line = f"git clone {omz_github} {omz_root}"
     try:
@@ -102,10 +123,11 @@ def omz_install(omz_root):
             )
 
     except Exception:
+        log_base(logfile).record("Error downloading Oh My ZSH. Aborted!", colorize=True)
         raise Exception("Error downloading Oh My ZSH. Aborted!")
 
 
-def omz_install_plugins(omz_root, plugins):
+def omz_install_plugins(omz_root, plugins, logfile):
     try:
         url_master = "https://github.com/zsh-users"
         for plugin in plugins:
@@ -116,10 +138,13 @@ def omz_install_plugins(omz_root, plugins):
                 command(clone, verbose=True)
                 printer(f"Plugin {plugin} task finished!", foreground=FG().FINISH)
     except Exception:
+        log_base(logfile).record(
+            "There was an error installing the plugin", colorize=True
+        )
         raise Exception("There was an error installing the plugin")
 
 
-def install_fonts(home, *, force=False) -> bool:
+def install_fonts(home, logfile, *, force=False) -> bool:
     url = "https://github.com/snakypy/assets"
     base_url = "blob/master/zshpower/fonts/terminal/fonts.zip?raw=true"
     font_name = "DejaVu Sans Mono Nerd Font"
@@ -148,11 +173,14 @@ def install_fonts(home, *, force=False) -> bool:
                 return True
             return False
         except Exception as err:
+            log_base(logfile).record(
+                f'Error downloading font "{font_name}"', colorize=True
+            )
             raise Exception(f'Error downloading font "{font_name}"', err)
     return False
 
 
-def add_plugins_zshrc(zshrc):
+def add_plugins_zshrc(zshrc, logfile):
     plugins = (
         "python",
         "django",
@@ -162,12 +190,12 @@ def add_plugins_zshrc(zshrc):
         "zsh-syntax-highlighting",
         "zsh-autosuggestions",
     )
-    current = plugins_current_zshrc(zshrc)
+    current = plugins_current_zshrc(zshrc, logfile)
 
     new_plugins = [plugin for plugin in plugins if plugin not in current]
 
     if len(new_plugins) > 0:
-        current_zshrc = read_zshrc(zshrc)
+        current_zshrc = read_zshrc(zshrc, logfile)
         plugins = f'plugins=({" ".join(current)} {" ".join(new_plugins)})'
         new_zsh_rc = re_sub(r"^plugins=\(.*", plugins, current_zshrc, flags=re_m)
         create_file(new_zsh_rc, zshrc, force=True)
@@ -175,8 +203,8 @@ def add_plugins_zshrc(zshrc):
     return ""
 
 
-def rm_source_zshrc(zshrc):
-    current_zshrc = read_zshrc(zshrc)
+def rm_source_zshrc(zshrc, logfile):
+    current_zshrc = read_zshrc(zshrc, logfile)
     line_rm = f"source\\ \\$HOME/.zshpower/{__info__['version']}/init.sh"
     new_zshrc = re_sub(rf"{line_rm}", "", current_zshrc, flags=re_m)
     create_file(new_zshrc, zshrc, force=True)
